@@ -12,3 +12,12 @@ except ImportError:
     IS_PANDAS_INSTALLED = False
 else:
     IS_PANDAS_INSTALLED = True
+
+
+try:
+    import jax  # noqa: F401
+    import jaxlib  # noqa: F401
+except ImportError:
+    IS_JAX_INSTALLED = False
+else:
+    IS_JAX_INSTALLED = True
